@@ -178,6 +178,7 @@ netest <- function(nw,
                   offset.coef.diss = coef.diss$coef.crude,
                   constraints = constraints,
                   estimate = "EGMME",
+                  eval.loglik = FALSE,
                   control = set.control.stergm)
 
     coef.form <- fit$formation.fit
@@ -186,6 +187,7 @@ netest <- function(nw,
     out$fit <- fit
     out$formation <- formation
     out$target.stats <- target.stats
+    out$target.stats.names <- names(fit$formation.fit$coef)[!fit$formation.fit$offset]
     out$coef.form <- coef.form$coef
     out$dissolution <- dissolution
     out$coef.diss <- coef.diss
@@ -225,7 +227,6 @@ netest <- function(nw,
 
     # Reduce size of output object
     fit$initialfit <- NULL
-    fit$newnetwork <- NULL
     fit$constrained <- NULL
     environment(fit$sample.obs) <- NULL
     environment(fit$reference) <- NULL
@@ -236,6 +237,11 @@ netest <- function(nw,
     out$fit <- fit
     out$formation <- formation
     out$target.stats <- target.stats
+    if (length(names(fit$coef)) == length(target.stats)) {
+      out$target.stats.names <- names(fit$coef)
+    } else {
+      out$target.stats.names <- names(fit$coef)[!fit$offset]
+    }
     out$coef.form <- coef.form
     out$coef.form.crude <- coef.form.crude
     out$dissolution <- dissolution
