@@ -476,8 +476,6 @@ plot.dcm <- function(x,
 #' @param sim.alpha transparency level for simulation lines, where 0 = transparent
 #'        and 1 = opaque (see \code{\link{transco}}).
 #' @param mean.line if \code{TRUE}, plot mean of simulations across time.
-#' @param mean.extinct if \code{TRUE}, include extinct simulations in mean
-#'        calculation (see details).
 #' @param mean.smooth if \code{TRUE}, use a lowess smoother on the mean line.
 #' @param mean.col a vector of any standard R color format for mean lines.
 #' @param mean.lwd line width for mean lines.
@@ -504,9 +502,7 @@ plot.dcm <- function(x,
 #' plots are individual simulation lines, means of the individual simulation
 #' lines, and quantiles of those individual simulation lines. The mean line,
 #' toggled on with \code{mean.line=TRUE} is calculated as the row mean
-#' across simulations at each time step. The \code{mean.extinct} will, if set to
-#' \code{FALSE}, exclude from this calculation any simulations with no incident
-#' cases of disease.
+#' across simulations at each time step.
 #'
 #' Compartment prevalences are the size of a compartment over some denominator.
 #' To plot the raw numbers from any compartment, use \code{popfrac=FALSE}; this
@@ -561,7 +557,6 @@ plot.icm <- function(x,
                      sim.lwd,
                      sim.alpha,
                      mean.line = TRUE,
-                     mean.extinct = TRUE,
                      mean.smooth = FALSE,
                      mean.col,
                      mean.lwd,
@@ -585,7 +580,6 @@ plot.icm <- function(x,
   if (max(sims) > nsims) {
     stop("Set sim to between 1 and ", nsims, call. = FALSE)
   }
-  nomeanlty <- ifelse(missing(mean.lty), TRUE, FALSE)
   type <- x$control$type
   if (class(x) == "icm") {
     modes <- x$param$groups
@@ -755,7 +749,7 @@ plot.icm <- function(x,
 
 
   # Quantiles ---------------------------------------------------------------
-  if (missing(qnts)) {
+  if (missing(qnts) || qnts == FALSE) {
     disp.qnts <- FALSE
   } else {
     disp.qnts <- TRUE
@@ -763,7 +757,7 @@ plot.icm <- function(x,
   if (nsims == 1) {
     disp.qnts <- FALSE
   }
-  if (modes == 1 & nocomp == TRUE & missing(qnts)) {
+  if (modes == 1 & missing(qnts)) {
     disp.qnts <- TRUE
     qnts <- 0.5
   }
@@ -771,115 +765,90 @@ plot.icm <- function(x,
     if (qnts > 1 | qnts < 0) {
       stop("qnts must be between 0 and 1", call. = FALSE)
     }
-    for (j in seq_len(lcomp)) {
-      quants <- c((1-qnts)/2, 1-((1-qnts)/2))
-      qnt.prev <- apply(x$epi[[y[j]]], 1,
-                        function(x) quantile(x, c(quants[1], quants[2])))
-      xx <- c(1:nsteps, nsteps:1)
-      yy <- c(qnt.prev[1,], rev(qnt.prev[2,]))
-      polygon(xx, yy, col = qnts.pal[j], border = NA)
-    }
+    draw_qnts(x, y, qnts, qnts.pal)
   }
 
 
   # Simulation lines --------------------------------------------------------
   if (missing(sim.lines)) {
-    if (modes == 1) {
-      sim.lines <- TRUE
-    } else {
-      sim.lines <- FALSE
-    }
+    sim.lines <- ifelse(modes == 1, TRUE, FALSE)
   }
   if (sim.lines == TRUE) {
-    if (nsims == 1) {
-      for (j in seq_len(lcomp)) {
-        lines(1:nsteps, x$epi[[y[j]]][, 1], lwd = sim.lwd[j], col = sim.pal[j])
-      }
-    }
-    if (nsims > 1) {
-      for (j in seq_len(lcomp)) {
-        for (i in sims) {
-          lines(1:nsteps, x$epi[[y[j]]][, i], lwd = sim.lwd[j], col = sim.pal[j])
-        }
+    for (j in seq_len(lcomp)) {
+      for (i in sims) {
+        lines(x$epi[[y[j]]][, i], lwd = sim.lwd[j], col = sim.pal[j])
       }
     }
   }
 
 
   # Mean lines --------------------------------------------------------------
-  if (!missing(mean.lwd) && length(mean.lwd) < lcomp) {
-    mean.lwd <- rep(mean.lwd, lcomp)
-  }
-  if (missing(mean.lwd)) {
-    mean.lwd <- rep(2.5, lcomp)
-  }
-  if (nomeanlty == TRUE) {
-    if (nocomp == TRUE) {
-      if (modes == 1) {
+  if (mean.line == TRUE) {
+
+    if (!missing(mean.lwd) && length(mean.lwd) < lcomp) {
+      mean.lwd <- rep(mean.lwd, lcomp)
+    }
+    if (missing(mean.lwd)) {
+      mean.lwd <- rep(2.5, lcomp)
+    }
+
+    if (!missing(mean.lty) && length(mean.lty) < lcomp) {
+      mean.lty <- rep(mean.lty, lcomp)
+    }
+    if (missing(mean.lty)) {
+      if (nocomp == FALSE || (nocomp == TRUE && modes == 1)) {
         mean.lty <- rep(1, lcomp)
-      }
-      if (modes == 2) {
+      } else {
         mean.lty <- rep(1:2, each = lcomp / 2)
       }
     }
-    if (nocomp == FALSE) {
-      mean.lty <- rep(1, lcomp)
-    }
-  }
-  if (nomeanlty == FALSE & length(mean.lty) < lcomp) {
-    mean.lty <- rep(mean.lty, lcomp)
-  }
-  if (mean.line == TRUE) {
-    if (nsims == 1) {
-      for (j in seq_len(lcomp)) {
-        mean.prev <- x$epi[[y[j]]][, 1]
-        if (mean.smooth == TRUE) {
-          mean.prev <- supsmu(x = 1:nsteps, y = mean.prev)$y
-        }
-        lines(1:nsteps,
-              mean.prev,
-              lwd = mean.lwd[j],
-              col = mean.pal[j],
-              lty = mean.lty[j])
-
-      }
-    }
-    if (nsims > 1) {
-      for (j in seq_len(lcomp)) {
-        if (mean.extinct == TRUE) {
-          mean.prev <- apply(x$epi[[y[j]]], 1, mean)
-          if (mean.smooth == TRUE) {
-            mean.prev <- supsmu(x = 1:nsteps, y = mean.prev)$y
-          }
-        } else {
-          non.extinct <- as.vector(which(apply(x$epi$si.flow, 2, max) > 0))
-          mean.prev <- apply(x$epi[[y[j]]][, non.extinct], 1, mean)
-          if (mean.smooth == TRUE) {
-            mean.prev <- supsmu(x = 1:nsteps, y = mean.prev)$y
-          }
-        }
-        lines(1:nsteps,
-              mean.prev,
-              lwd = mean.lwd[j],
-              col = mean.pal[j],
-              lty = mean.lty[j])
-      }
-    }
+    draw_means(x, y, mean.smooth, mean.lwd, mean.pal, mean.lty)
   }
 
 
   # Legends -----------------------------------------------------------------
-  if (missing(leg)) {
-    leg <- FALSE
+  if (!missing(leg) && leg == TRUE) {
+    leg.lty <- ifelse(modes == 2 & nocomp == TRUE, mean.lty, 1)
+    legend("topright", legend = y, lty = leg.lty, lwd = 3,
+           col = mean.pal, cex = leg.cex, bg = "white")
   }
-  if (leg == TRUE) {
-    if (modes == 2 & nocomp) {
-      legend("topright", legend = y, lty = mean.lty, lwd = 3,
-             col = mean.pal, cex = leg.cex, bg = "white")
+
+}
+
+
+## Helper utilities
+draw_qnts <- function(x, y, qnts, qnts.pal, loc = "epi") {
+
+  lcomp <- length(y)
+  for (j in seq_len(lcomp)) {
+    quants <- c((1-qnts)/2, 1-((1-qnts)/2))
+    qnt.prev <- apply(x[[loc]][[y[j]]], 1,
+                      function(x) quantile(x, c(quants[1], quants[2])))
+    xx <- c(1:(ncol(qnt.prev)), (ncol(qnt.prev)):1)
+    yy <- c(qnt.prev[1,], rev(qnt.prev[2,]))
+    polygon(xx, yy, col = qnts.pal[j], border = NA)
+  }
+
+}
+
+
+draw_means <- function(x, y, mean.smooth, mean.lwd,
+                       mean.pal, mean.lty, loc = "epi") {
+
+  lcomp <- length(y)
+  nsims <- x$control$nsims
+
+  for (j in seq_len(lcomp)) {
+    if (nsims == 1) {
+      mean.prev <- x[[loc]][[y[j]]][, 1]
     } else {
-      legend("topright", legend = y, lty = 1, lwd = 3,
-             col = mean.pal, cex = leg.cex, bg = "white")
+      mean.prev <- rowMeans(x[[loc]][[y[j]]])
     }
+    if (mean.smooth == TRUE) {
+      mean.prev <- supsmu(x = 1:length(mean.prev), y = mean.prev)$y
+    }
+    lines(mean.prev, lwd = mean.lwd[j],
+          col = mean.pal[j], lty = mean.lty[j])
   }
 
 }
@@ -890,29 +859,45 @@ plot.icm <- function(x,
 #' @description Plots dynamic network model diagnostics calculated in
 #'              \code{netdx}.
 #'
-#' @param x an \code{EpiModel} object of class \code{netdx}.
-#' @param type plot type, with options of \code{"formation"} for network
+#' @param x An \code{EpiModel} object of class \code{netdx}.
+#' @param type Plot type, with options of \code{"formation"} for network
 #'        model formation statistics, \code{"duration"} for dissolution model
 #'        statistics for average edge duration, or \code{"dissolution"} for
 #'        dissolution model statistics for proportion of ties dissolved per time
 #'        step.
-#' @param sim vector of simulation numbers to plot, with the default to plot
+#' @param method Plot method, with options of \code{"l"} for line plots and
+#'        \code{"b"} for boxplots.
+#' @param sim Vector of simulation numbers to plot, with the default to plot
 #'        all simulations.
-#' @param stats network statistics to plot, among those specified in the call
+#' @param stats Network statistics to plot, among those specified in the call
 #'        to \code{\link{netdx}}, with the default to plot all statistics
 #'        contained in the object.
-#' @param sim.col vector of standard R colors for individual simulation lines,
+#' @param sim.lines If \code{TRUE}, plot individual simulation lines.
+#' @param sim.col Vector of standard R colors for individual simulation lines,
 #'        with default colors based on \code{RColorBrewer} color palettes.
-#' @param sim.lwd line width for individual simulation lines, with defaults based
+#' @param sim.lwd Line width for individual simulation lines, with defaults based
 #'        on number of simulations (more simulations results in thinner lines).
-#' @param sim.lty line type for the individual simulation lines.
-#' @param targ.col vector of standard R colors for target statistic lines, with
+#' @param sim.lty Line type for the individual simulation lines.
+#' @param mean.line If \code{TRUE}, plot mean of simulations across time.
+#' @param mean.smooth If \code{TRUE}, use a lowess smoother on the mean line.
+#' @param mean.col A vector of any standard R color format for mean lines.
+#' @param mean.lwd Line width for mean lines.
+#' @param mean.lty Line type for mean lines.
+#' @param qnts If numeric, plot polygon of simulation quantiles based on the
+#'        range implied by the argument (0.5 is the middle 50% of the data).
+#'        If \code{FALSE}, suppress polygon from plot.
+#' @param qnts.col Vector of any standard R color format for polygons.
+#' @param qnts.alpha Transparency level for quantile polygons, where 0 =
+#'        transparent and 1 = opaque (see \code{\link{transco}}).
+#' @param targ.line If \code{TRUE}, plot target or expected value line for
+#'        the statistic of interest.
+#' @param targ.col Vector of standard R colors for target statistic lines, with
 #'        default colors based on \code{RColorBrewer} color palettes.
-#' @param targ.lwd line width for the line showing the target statistic values.
-#' @param targ.lty line type for the line showing the target statistic values.
-#' @param plots.joined if \code{TRUE}, combine all target statistics in one plot,
+#' @param targ.lwd Line Width for the line showing the target statistic values.
+#' @param targ.lty Line Type for the line showing the target statistic values.
+#' @param plots.joined If \code{TRUE}, combine all target statistics in one plot,
 #'        otherwise use one plot window per target statistic.
-#' @param plot.leg if \code{TRUE}, show legend (only if \code{plots.joined=TRUE})
+#' @param plot.leg If \code{TRUE}, show legend (only if \code{plots.joined=TRUE})
 #' @param ... additional arguments passed to main plot windows.
 #'
 #' @details
@@ -955,49 +940,72 @@ plot.icm <- function(x,
 #' formation <- ~ edges + nodematch("sex")
 #' dissolution <- ~ offset(edges)
 #' target.stats <- c(50, 40)
-#' coef.diss <- dissolution_coefs(dissolution, duration = 10)
+#' coef.diss <- dissolution_coefs(dissolution, duration = 50)
 #'
 #' # Estimate the model
-#' est <- netest(nw,
-#'               formation,
-#'               dissolution,
-#'               target.stats,
-#'               coef.diss,
-#'               verbose = FALSE)
+#' est <- netest(nw, formation, dissolution,
+#'               target.stats, coef.diss, verbose = FALSE)
 #'
-#' # Run diagnostics
-#' dx <- netdx(est,
-#'             nsims = 10,
-#'             nsteps = 100,
-#'             nwstats.formula = ~ edges + meandeg + concurrent +
-#'                                 nodefactor("sex", base = 0) +
-#'                                 nodematch("sex"),
-#'             verbose = FALSE)
+#' # Static diagnostics
+#' dx1 <- netdx(est, nsims = 1e4, dynamic = FALSE,
+#'              nwstats.formula = ~ edges + meandeg + concurrent +
+#'                                  nodefactor("sex", base = 0) +
+#'                                  nodematch("sex"))
+#' dx1
+#'
+#' # Only formation diagnostics are available to plot
+#' plot(dx1, stats = "edges")
+#' plot(dx1, stats = "edges", method = "b", col = "seagreen3")
+#' plot(dx1, stats = c("nodefactor.sex.0", "nodefactor.sex.1"), method = "b")
+#'
+#' # Dynamic diagnostics
+#' dx2 <- netdx(est, nsims = 10, nsteps = 500,
+#'              nwstats.formula = ~ edges + meandeg + concurrent +
+#'                                  nodefactor("sex", base = 0) +
+#'                                  nodematch("sex"))
+#' dx2
 #'
 #' # Formation statistics plots, joined and separate
-#' plot(dx, type = "formation")
-#' plot(dx, type = "formation", plots.joined = TRUE)
-#' plot(dx, type = "formation", sim = 2:5)
-#' plot(dx, type = "formation", plots.joined = FALSE,
+#' plot(dx2)
+#' plot(dx2, type = "formation", plots.joined = TRUE)
+#' plot(dx2, type = "formation", sim = 1, plots.joined = TRUE)
+#' plot(dx2, type = "formation", plots.joined = FALSE,
 #'      stats = c("edges", "concurrent"))
-#' plot(dx, type = "formation", stats = "nodefactor.sex.0",
+#' plot(dx2, type = "formation", stats = "nodefactor.sex.0",
 #'      sim = 1, sim.lwd = 5, sim.col = "darkmagenta")
 #'
+#' plot(dx2, method = "b", col = "bisque")
+#' plot(dx2, method = "b", stats = "meandeg", col = "dodgerblue")
+#'
 #' # Duration statistics plot
-#' plot(dx, type = "duration")
-#' plot(dx, type = "duration", sim = 1)
-#' plot(dx, type = "duration", sim = 10,
+#' plot(dx2, type = "duration")
+#' plot(dx2, type = "duration", sim = 10,
 #'      sim.col = "steelblue", sim.lwd = 3,
 #'      targ.lty = 1, targ.lwd = 0.5)
+#'
+#' # Dissolution statistics plot
+#' plot(dx2, type = "dissolution")
+#' plot(dx2, type = "dissolution", method = "b", col = "pink1")
 #' }
 #'
 plot.netdx <- function(x,
                        type = "formation",
+                       method = "l",
                        sim,
                        stats,
+                       sim.lines = TRUE,
                        sim.col,
                        sim.lwd,
                        sim.lty = 1,
+                       mean.line = TRUE,
+                       mean.smooth = FALSE,
+                       mean.col,
+                       mean.lwd = 2,
+                       mean.lty = 1,
+                       qnts = FALSE,
+                       qnts.col,
+                       qnts.alpha,
+                       targ.line = TRUE,
                        targ.col,
                        targ.lwd = 2,
                        targ.lty = 2,
@@ -1014,6 +1022,11 @@ plot.netdx <- function(x,
     stop("x must be an object of class netdx", call. = FALSE)
   }
 
+  if (x$dynamic == FALSE && type %in% c("duration", "dissolution")) {
+    stop("Plots of type duration and dissolution only available if netdx run with dynamic = TRUE",
+         call. = FALSE)
+  }
+
   ## Check sims
   nsims <- x$nsims
   if (missing(sim)) {
@@ -1023,6 +1036,7 @@ plot.netdx <- function(x,
     stop("Maximum sim number is", nsims, call. = FALSE)
   }
   nsteps <- x$nsteps
+  dynamic <- x$dynamic
 
   # Get dotargs
   da <- list(...)
@@ -1036,7 +1050,7 @@ plot.netdx <- function(x,
     nwstats.table <- x$stats.table.formation
 
     ## Find available stats
-    sts <- which(!is.na(nwstats.table$stats.means))
+    sts <- which(!is.na(nwstats.table[, "Sim Mean"]))
     nmstats <- rownames(nwstats.table)[sts]
 
     ## Pull and check stat argument
@@ -1055,7 +1069,7 @@ plot.netdx <- function(x,
     data <- data[, colnames(data) %in% nmstats[outsts], drop = FALSE]
 
     ## Pull target stats
-    targs <- which(!is.na(nwstats.table$targets))
+    targs <- which(!is.na(nwstats.table$Target))
 
 
     ## Plotting
@@ -1067,13 +1081,21 @@ plot.netdx <- function(x,
       plots.joined <- TRUE
     }
 
-    xlim <- c(1, nsteps)
-    if (length(da) > 0 && !is.null(da$xlim)) {
-      xlim <- da$xlim
+    if (dynamic == TRUE) {
+      xlim <- c(1, nsteps)
+      if (length(da) > 0 && !is.null(da$xlim)) {
+        xlim <- da$xlim
+      }
+    } else {
+      xlim <- c(1, nsims)
+      if (length(da) > 0 && !is.null(da$xlim)) {
+        xlim <- da$xlim
+      }
     }
 
+
     if (missing(sim.lwd)) {
-      if (nsims == 1) {
+      if (nsims == 1 | dynamic == FALSE) {
         sim.lwd <- 1
       } else {
         sim.lwd <- max(c(1-(nsims*0.05), 0.5))
@@ -1094,125 +1116,233 @@ plot.netdx <- function(x,
 
 
     ## Joined Plots
-    if (plots.joined == TRUE) {
+    if (method == "l") {
+      if (plots.joined == TRUE) {
 
-      ## Default legend
-      if (nstats == 1) {
-        if (missing(plot.leg)) {
-          plot.leg <- FALSE
-        }
-      }
-
-      ## Default ylim
-      ylim <- c(min(data) * 0.8, max(data) * 1.2)
-      if (length(da) > 0 && !is.null(da$ylim)) {
-        ylim <- da$ylim
-      }
-
-      ## Default ylab
-      if (length(da) > 0 && !is.null(da$ylab)) {
-        ylab <- da$ylab
-      } else {
+        ## Default legend
         if (nstats == 1) {
-          ylab <- nmstats[outsts]
-        } else {
-          ylab <- "Statistic"
+          if (missing(plot.leg)) {
+            plot.leg <- FALSE
+          }
         }
-      }
 
-      ## Default xlab
-      if (length(da) > 0 && !is.null(da$xlab)) {
-        xlab <- da$xlab
-      } else {
-        xlab <- "time"
-      }
-
-      ## Default target line color
-      if (missing(targ.col)) {
-        if (nstats == 1) {
-          targ.col <- "black"
-        } else if (nstats > 9) {
-          targ.col <- brewer_ramp(nstats, "Set1")
-        } else {
-          targ.col <- brewer.pal(9, "Set1")[1:nstats]
+        ## Default ylim
+        ylim <- c(min(data) * 0.8, max(data) * 1.2)
+        if (length(da) > 0 && !is.null(da$ylim)) {
+          ylim <- da$ylim
         }
+
+        ## Default ylab
+        if (length(da) > 0 && !is.null(da$ylab)) {
+          ylab <- da$ylab
+        } else {
+          if (nstats == 1) {
+            ylab <- nmstats[outsts]
+          } else {
+            ylab <- "Statistic"
+          }
+        }
+
+        ## Default xlab
+        if (dynamic == TRUE) {
+          if (length(da) > 0 && !is.null(da$xlab)) {
+            xlab <- da$xlab
+          } else {
+            xlab <- "time"
+          }
+        } else {
+          if (length(da) > 0 && !is.null(da$xlab)) {
+            xlab <- da$xlab
+          } else {
+            xlab <- "simulation number"
+          }
+        }
+
+
+        ## Default target line color
+        if (missing(targ.col)) {
+          targ.col <- sim.col
+        }
+
+
+        ## Main plot window
+        plot(1, 1, xlim = xlim, ylim = ylim,
+             type = "n", xlab = xlab, ylab = ylab)
+        for (j in outsts) {
+          dataj <- data[, colnames(data) %in% nmstats[j], drop = FALSE]
+
+          if (is.numeric(qnts)) {
+            if (qnts < 0 | qnts > 1) {
+              stop("qnts must be between 0 and 1", call. = FALSE)
+            }
+            if (missing(qnts.col)) {
+              qnts.col <- sim.col
+            }
+            if (missing(qnts.alpha)) {
+              qnts.alpha <- 0.75
+            }
+            qnts.col <- transco(qnts.col, qnts.alpha)
+            quants <- c((1-qnts)/2, 1-((1-qnts)/2))
+            qnt.prev <- apply(dataj, 1, function(x) quantile(x, c(quants[1], quants[2])))
+            xx <- c(1:(ncol(qnt.prev)), (ncol(qnt.prev)):1)
+            yy <- c(qnt.prev[1,], rev(qnt.prev[2,]))
+            polygon(xx, yy, col = qnts.col[which(j == outsts)], border = NA)
+          }
+
+          if (sim.lines == TRUE) {
+            if (dynamic == TRUE) {
+              for (i in sim) {
+                lines(dataj[,i],
+                      lty = sim.lty, lwd = sim.lwd,
+                      col = sim.col[which(j == outsts)])
+              }
+            } else {
+              lines(dataj,
+                    lty = sim.lty, lwd = sim.lwd,
+                    col = sim.col[which(j == outsts)])
+            }
+          }
+          if (mean.line == TRUE) {
+            if (missing(mean.col)) {
+              mean.col <- sim.col
+            }
+            mean.prev <- rowMeans(dataj)
+            if (mean.smooth == TRUE) {
+              mean.prev <- supsmu(x = 1:length(mean.prev), y = mean.prev)$y
+            }
+            lines(mean.prev, lwd = mean.lwd,
+                  col = mean.col[which(j == outsts)], lty = mean.lty)
+          }
+
+          if (targ.line == TRUE) {
+            if (j %in% targs) {
+              abline(h = nwstats.table$Target[j],
+                     lty = targ.lty, lwd = targ.lwd,
+                     col = targ.col[which(j == outsts)])
+            }
+          }
+
+        }
+        if (plot.leg == TRUE) {
+          legend("topleft", legend = nmstats[outsts],
+                 lwd = 3, lty = sim.lty,
+                 col = sim.col[1:nstats], cex = 0.75,
+                 bg = "white")
+        }
+
       }
 
+      ## Split plots
+      if (plots.joined == FALSE) {
+
+        if (nstats == 1) dimens <- c(1, 1)
+        if (nstats == 2) dimens <- c(1, 2)
+        if (nstats == 3) dimens <- c(1, 3)
+        if (nstats == 4) dimens <- c(2, 2)
+        if (nstats == 5) dimens <- c(2, 3)
+        if (nstats == 6) dimens <- c(2, 3)
+        if (nstats %in% 7:9) dimens <- c(3, 3)
+        if (nstats %in% 10:12) dimens <- c(4, 3)
+        if (nstats %in% 13:16) dimens <- c(4, 4)
+        if (nstats > 16) dimens <- rep(ceiling(sqrt(nstats)), 2)
+
+        # Pull graphical parameters
+        ops <- list(mar = par()$mar, mfrow = par()$mfrow, mgp = par()$mgp)
+        par(mar = c(2.5, 2.5, 2, 1), mgp = c(2, 1, 0), mfrow = dimens)
+
+        if (missing(targ.col)) {
+          targ.col <- rep("black", nstats)
+        }
+
+        for (j in outsts) {
+          dataj <- data[, colnames(data) %in% nmstats[j], drop = FALSE]
+          plot(x = 1, y = 1,
+               xlim = xlim,
+               ylim = c(min(dataj) * 0.8, max(dataj) * 1.2),
+               type = "n", main = nmstats[j],
+               xlab = "", ylab = "")
+
+          if (is.numeric(qnts)) {
+            if (qnts < 0 | qnts > 1) {
+              stop("qnts must be between 0 and 1", call. = FALSE)
+            }
+            if (missing(qnts.col)) {
+              qnts.col <- sim.col
+            }
+            if (missing(qnts.alpha)) {
+              qnts.alpha <- 0.75
+            }
+            qnts.col <- transco(qnts.col, qnts.alpha)
+            quants <- c((1-qnts)/2, 1-((1-qnts)/2))
+            qnt.prev <- apply(dataj, 1, function(x) quantile(x, c(quants[1], quants[2])))
+            xx <- c(1:(ncol(qnt.prev)), (ncol(qnt.prev)):1)
+            yy <- c(qnt.prev[1,], rev(qnt.prev[2,]))
+            polygon(xx, yy, col = qnts.col[which(j == outsts)], border = NA)
+          }
+
+          if (sim.lines == TRUE) {
+            if (dynamic == TRUE) {
+              for (i in sim) {
+                lines(dataj[, i],
+                      lwd = sim.lwd, lty = sim.lty,
+                      col = sim.col[which(j == outsts)])
+              }
+            } else {
+              lines(dataj,
+                    lwd = sim.lwd, lty = sim.lty,
+                    col = sim.col[which(j == outsts)])
+            }
+          }
+
+          if (mean.line == TRUE) {
+            if (missing(mean.col)) {
+              mean.col <- sim.col
+            }
+            mean.prev <- rowMeans(dataj)
+            if (mean.smooth == TRUE) {
+              mean.prev <- supsmu(x = 1:length(mean.prev), y = mean.prev)$y
+            }
+            lines(mean.prev, lwd = mean.lwd,
+                  col = mean.col[which(j == outsts)], lty = mean.lty)
+          }
+
+          if (targ.line == TRUE) {
+            if (j %in% targs) {
+              abline(h = nwstats.table$Target[j],
+                     lty = targ.lty, lwd = targ.lwd,
+                     col = targ.col[which(j == outsts)])
+            }
+          }
+        }
+
+        # Reset graphical parameters
+        on.exit(par(ops))
+      }
+    }
+    if (method == "b") {
+
+      data <- list()
+      for (j in seq_along(stats)) {
+        data[[j]] <- unlist(lapply(nwstats, function(x) x[,stats[j]]))
+      }
+      data <- do.call("cbind", data)
+      colnames(data) <- stats
+
+      boxplot(data, ...)
 
-      ## Main plot window
-      plot(1, 1, xlim = xlim, ylim = ylim,
-           type = "n", xlab = xlab, ylab = ylab)
       for (j in outsts) {
-        dataj <- data[, colnames(data) %in% nmstats[j], drop = FALSE]
-        for (i in sim) {
-          lines(x = 1:nsteps,
-                y = dataj[,i],
-                lty = sim.lty, lwd = sim.lwd,
-                col = sim.col[which(j == outsts)])
-        }
         if (j %in% targs) {
-          abline(h = nwstats.table$targets[j],
-                 lty = targ.lty, lwd = targ.lwd,
-                 col = targ.col[which(j == outsts)])
+          points(x = outsts[j], y = nwstats.table$Target[j],
+                 pch = 16, cex = 1.5, col = "blue")
         }
       }
-      if (plot.leg == TRUE) {
-        legend("topleft", legend = nmstats[outsts],
-               lwd = 3, lty = sim.lty,
-               col = sim.col[1:nstats], cex = 0.75,
-               bg = "white")
-      }
 
     }
 
-    ## Split plots
-    if (plots.joined == FALSE) {
-
-      if (nstats == 1) dimens <- c(1, 1)
-      if (nstats == 2) dimens <- c(1, 2)
-      if (nstats == 3) dimens <- c(1, 3)
-      if (nstats == 4) dimens <- c(2, 2)
-      if (nstats == 5) dimens <- c(2, 3)
-      if (nstats == 6) dimens <- c(2, 3)
-      if (nstats %in% 7:9) dimens <- c(3, 3)
-      if (nstats %in% 10:12) dimens <- c(4, 3)
-      if (nstats %in% 13:16) dimens <- c(4, 4)
-      if (nstats > 16) dimens <- rep(ceiling(sqrt(nstats)), 2)
-
-      # Pull graphical parameters
-      ops <- list(mar = par()$mar, mfrow = par()$mfrow, mgp = par()$mgp)
-      par(mar = c(2.5, 2.5, 2, 1), mgp = c(2, 1, 0), mfrow = dimens)
-
-      if (missing(targ.col)) {
-        targ.col <- rep("black", nstats)
-      }
-
-      for (j in outsts) {
-        dataj <- data[, colnames(data) %in% nmstats[j], drop = FALSE]
-        plot(x = 1, y = 1,
-             xlim = xlim,
-             ylim = c(min(dataj) * 0.8, max(dataj) * 1.2),
-             type = "n", main = nmstats[j],
-             xlab = "", ylab = "")
-        for (i in sim) {
-          lines(x = 1:nsteps,
-                y = dataj[, i],
-                lwd = sim.lwd, lty = sim.lty,
-                col = sim.col[which(j == outsts)])
-        }
-        if (j %in% targs) {
-          abline(h = nwstats.table$targets[j],
-                 lty = targ.lty, lwd = targ.lwd,
-                 col = targ.col[which(j == outsts)])
-        }
-      }
-
-      # Reset graphical parameters
-      on.exit(par(ops))
-    }
   }
 
   # Duration plot -----------------------------------------------------------
+
   if (type == "duration") {
 
     pages <- x$pages
@@ -1252,25 +1382,69 @@ plot.netdx <- function(x,
       xlab <- "time"
     }
 
-    # Edges only dissolution model
-    if (x$dissolution == ~offset(edges)) {
-
+    if (method == "l") {
       plot(x = 1, y = 1, type = "n",
            xlim = xlim, ylim = ylim,
            xlab = xlab, ylab = ylab)
-      for (i in sim) {
-        lines(x = 1:nsteps,
-              y = pages[[i]],
-              lwd = sim.lwd, lty = sim.lty,
-              col = sim.col)
+
+      if (is.numeric(qnts)) {
+        if (qnts < 0 | qnts > 1) {
+          stop("qnts must be between 0 and 1", call. = FALSE)
+        }
+        if (missing(qnts.col)) {
+          qnts.col <- sim.col
+        }
+        if (missing(qnts.alpha)) {
+          qnts.alpha <- 0.75
+        }
+        qnts.col <- transco(qnts.col, qnts.alpha)
+        quants <- c((1-qnts)/2, 1-((1-qnts)/2))
+        dataj <- as.data.frame(pages)
+        qnt.prev <- apply(dataj, 1, function(x)
+                          quantile(x, c(quants[1], quants[2]),
+                                   na.rm = TRUE))
+        xx <- c(1:(ncol(qnt.prev)), (ncol(qnt.prev)):1)
+        yy <- c(qnt.prev[1,], rev(qnt.prev[2,]))
+        polygon(xx, yy, col = qnts.col, border = NA)
+      }
+
+      ## Sim lines
+      if (sim.lines == TRUE) {
+        for (i in sim) {
+          lines(x = 1:nsteps,
+                y = pages[[i]],
+                lwd = sim.lwd, lty = sim.lty,
+                col = sim.col)
+        }
+      }
+
+      if (mean.line == TRUE) {
+        if (missing(mean.col)) {
+          mean.col <- sim.col
+        }
+        dataj <- as.data.frame(pages)
+        mean.prev <- rowMeans(dataj)
+        if (mean.smooth == TRUE) {
+          mean.prev <- supsmu(x = 1:length(mean.prev), y = mean.prev)$y
+        }
+        lines(mean.prev, lwd = mean.lwd,
+              col = mean.col, lty = mean.lty)
+      }
+
+      if (targ.line == TRUE) {
+        abline(h = as.numeric(x$coef.diss[2]),
+               lty = targ.lty, lwd = targ.lwd,
+               col = targ.col)
       }
-      abline(h = as.numeric(x$coef.diss[2]),
-             lty = targ.lty, lwd = targ.lwd,
-             col = targ.col)
-    } else {
-      stop("Only ~offset(edges) dissolution models currently supported",
-           call. = FALSE)
     }
+
+    if (method == "b") {
+      data <- do.call("c", x$pages)
+      boxplot(data, ...)
+      points(x = 1, y = as.numeric(x$coef.diss[2]),
+             pch = 16, cex = 1.5, col = "blue")
+    }
+
   }
 
   # Dissolution plot -----------------------------------------------------------
@@ -1303,7 +1477,7 @@ plot.netdx <- function(x,
     if (length(da) > 0 && !is.null(da$ylab)) {
       ylab <- da$ylab
     } else {
-      ylab <- "Prop. Edges Dissolving"
+      ylab <- "Pct Edges Diss"
     }
 
     # Default xlab
@@ -1313,25 +1487,69 @@ plot.netdx <- function(x,
       xlab <- "time"
     }
 
-    # Edges only dissolution model
-    if (x$dissolution == ~offset(edges)) {
-
+    if (method == "l") {
       plot(x = 1, y = 1, type = "n",
            xlim = xlim, ylim = ylim,
            xlab = xlab, ylab = ylab)
-      for (i in sim) {
-        lines(x = 1:nsteps,
-              y = prop.diss[[i]],
-              lwd = sim.lwd, lty = sim.lty,
-              col = sim.col)
+
+      if (is.numeric(qnts)) {
+        if (qnts < 0 | qnts > 1) {
+          stop("qnts must be between 0 and 1", call. = FALSE)
+        }
+        if (missing(qnts.col)) {
+          qnts.col <- sim.col
+        }
+        if (missing(qnts.alpha)) {
+          qnts.alpha <- 0.75
+        }
+        qnts.col <- transco(qnts.col, qnts.alpha)
+        quants <- c((1-qnts)/2, 1-((1-qnts)/2))
+        dataj <- as.data.frame(prop.diss)
+        qnt.prev <- apply(dataj, 1, function(x)
+          quantile(x, c(quants[1], quants[2]),
+                   na.rm = TRUE))
+        xx <- c(1:(ncol(qnt.prev)), (ncol(qnt.prev)):1)
+        yy <- c(qnt.prev[1,], rev(qnt.prev[2,]))
+        polygon(xx, yy, col = qnts.col, border = NA)
+      }
+
+      # Sim lines
+      if (sim.lines == TRUE) {
+        for (i in sim) {
+          lines(x = 1:nsteps,
+                y = prop.diss[[i]],
+                lwd = sim.lwd, lty = sim.lty,
+                col = sim.col)
+        }
+      }
+
+      if (mean.line == TRUE) {
+        if (missing(mean.col)) {
+          mean.col <- sim.col
+        }
+        dataj <- as.data.frame(prop.diss)
+        mean.prev <- rowMeans(dataj)
+        if (mean.smooth == TRUE) {
+          mean.prev <- supsmu(x = 1:length(mean.prev), y = mean.prev)$y
+        }
+        lines(mean.prev, lwd = mean.lwd,
+              col = mean.col, lty = mean.lty)
+      }
+
+      if (targ.line == TRUE) {
+        abline(h = as.numeric(1/(x$coef.diss[2]$duration)),
+               lty = targ.lty, lwd = targ.lwd,
+               col = targ.col)
       }
-      abline(h = as.numeric(1/(x$coef.diss[2]$duration)),
-             lty = targ.lty, lwd = targ.lwd,
-             col = targ.col)
-    } else {
-      stop("Only ~offset(edges) dissolution models currently supported",
-           call. = FALSE)
     }
+
+    if (method == "b") {
+      data <- do.call("c", x$prop.diss)
+      boxplot(data, ...)
+      points(x = 1, y = as.numeric(1/(x$coef.diss[2]$duration)),
+             pch = 16, cex = 1.5, col = "blue")
+    }
+
   }
 
 }
